pub struct StaticStringDependency {
pub codec: StringCodec,
pub len: u32,
pub ptr: *const u8,
}Expand description
StaticStringDependency serializes the value of the pointer and the contents of the string It is designed to be wire-compatible with the unreal instrumentation
Fields
codec: StringCodeclen: u32ptr: *const u8Trait Implementations
Sourceimpl Debug for StaticStringDependency
impl Debug for StaticStringDependency
Sourceimpl InProcSerialize for StaticStringDependency
impl InProcSerialize for StaticStringDependency
const IN_PROC_SIZE: InProcSize = InProcSize::Dynamic
fn get_value_size(&self) -> Option<u32>
fn write_value(&self, buffer: &mut Vec<u8>)
Sourceunsafe fn read_value(_window: &[u8]) -> Self
unsafe fn read_value(_window: &[u8]) -> Self
Safety Read more
Sourceimpl Reflect for StaticStringDependency
impl Reflect for StaticStringDependency
fn reflect() -> UserDefinedType