Utf8StaticStringDependency

Struct Utf8StaticStringDependency 

pub struct Utf8StaticStringDependency {
    pub len: u32,
    pub ptr: *const u8,
}
Utf8StaticStringDependency serializes the value of the pointer and the contents of the string It should not be part of the event - it’s the dependency of the StringId

Fields

len: u32ptr: *const u8