pub struct Utf8StaticStringDependency {
pub len: u32,
pub ptr: *const u8,
}Expand description
Utf8StaticStringDependency serializes the value of the pointer and the contents of the string It should not be part of the event - it’s the dependency of the StringId
Fields
len: u32ptr: *const u8Trait Implementations
Sourceimpl Debug for Utf8StaticStringDependency
impl Debug for Utf8StaticStringDependency
Sourceimpl From<&str> for Utf8StaticStringDependency
impl From<&str> for Utf8StaticStringDependency
Sourceimpl InProcSerialize for Utf8StaticStringDependency
impl InProcSerialize for Utf8StaticStringDependency
const IN_PROC_SIZE: InProcSize = InProcSize::Dynamic
fn get_value_size(&self) -> Option<u32>
fn write_value(&self, buffer: &mut Vec<u8>)
Sourceunsafe fn read_value(window: &[u8]) -> Self
unsafe fn read_value(window: &[u8]) -> Self
Safety Read more
Sourceimpl Reflect for Utf8StaticStringDependency
impl Reflect for Utf8StaticStringDependency
fn reflect() -> UserDefinedType